@@ -4,12 +4,12 @@
 #'@param file a string that contains the path to the file
 #'@export
 DSD_SubspaceARFFStream <- function(file) {
-  jref <- rJava::.jcall("DataStreamBuilder",
-                        returnSig="Lmoa/streams/clustering/SubspaceARFFStream;",
-                        method="buildSubspaceARFFStream",
+  jref <- rJava::.jcall("moa/r_interface/RCompatibleDataStream",
+                        returnSig="Lmoa/r_interface/RCompatibleDataStream;",
+                        method="subspaceArff",
                         file)
   
-  numAtts <- rJava::.jcall("DataStreamAccessor","I","getNumAtts",jref)
+  numAtts <- rJava::.jcall(jref,"I","getNumAtts")
   res <- structure(list(description="A data stream read from a file.",
                         javaObj=jref,d=numAtts
   ),
